@@ -1,5 +1,4 @@
 <?php
-declare(encoding = 'utf-8');
 require_once 'Person.php';
 require_once 'CA.php';
 require_once 'key_sign.php';
@@ -237,9 +236,10 @@ class CA_Comodo extends CA
 		}
 
         $uid = $this->person->getEPPN();
+
         $organization = 'O=' . $this->person->getSubscriber()->getOrgName();
 
-        $params = $this->capiGetEPPNCertList($uid, $days);
+		$params = $this->capiGetEPPNCertList($uid, $days);
         $res=array();
 		$dates = array();
 		/* initiallize the array with a high value, so that the cache stays
@@ -792,6 +792,10 @@ class CA_Comodo extends CA
 
 	private function capiGetEPPNCertList($eppn, $days)
 	{
+		if($eppn=='') {
+			$msg = "No valid user information ";
+			throw new CGE_ComodoAPIException($msg);
+		} else {
 		Logger::log_event(LOG_DEBUG, "Trying to get the the list of the certificates " .
 		                             "for user $eppn");
 		$list_endpoint = ConfusaConstants::$CAPI_LISTING_ENDPOINT;
@@ -830,6 +834,7 @@ class CA_Comodo extends CA
 			                                 "certificates from the remote-API: " .
 			                                 $params['errorMessage'] . $msg
 				);
+			}
 		}
 	} /* end capiGetEPPNCertList */
 
