@@ -294,7 +294,7 @@ class CP_Admin extends Content_Page
 			try {
 				/* Get a list of subscribers (as
 				 * Subscriber-objects) */
-				$subscribers = $this->person->getNREN()->getSubscriberList();
+				$subscribers = $this->person->getNREN()->getSubscriberList('name');
 			} catch (DBQueryException $dbqe) {
 				Framework::error_output("Cannot retrieve subscriber from database!<br /> " .
 				                        "Probably wrong syntax for query, ask an admin to investigate." .
@@ -360,7 +360,7 @@ class CP_Admin extends Content_Page
 
 		/* Get all subscriber-admins */
 		$subscriber_admins = $this->getSubscriberAdmins($subscriber_id, SUBSCRIBER_ADMIN);
-		$this->tpl->assign('subscriber', $subscriber_db);
+		$this->tpl->assign('subscriber', $this->person->getSubscriber());
 		$this->tpl->assign('subscriber_admins', $subscriber_admins);
 
 		/* get a list of all subadmins */
